==> haskell-libxml-0.1.1-21-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libxml
version:              0.1.1
visibility:           public
id:                   libxml-0.1.1-1oII4JsRtkfGmKDXNxv79B
key:                  libxml-0.1.1-1oII4JsRtkfGmKDXNxv79B
license:              BSD-3-Clause
copyright:            2006, Lemmih
maintainer:           Lemmih (lemmih@gmail.com)
author:               Lemmih (lemmih@gmail.com)
synopsis:             Binding to libxml2
description:
    Minimal binding to libxml2. Additional functions will be added when needed.

category:             XML
abi:                  2dcbab267caa52d51ea1d5f248b273b0
exposed:              True
exposed-modules:
    Text.XML.LibXML Text.XML.LibXML.Internals Text.XML.LibXML.Parser
    Text.XML.LibXML.Tree Text.XML.LibXML.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/libxml-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/libxml-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libxml
hs-libraries:         HSlibxml-0.1.1-1oII4JsRtkfGmKDXNxv79B
extra-libraries:      xml2
include-dirs:         /usr/include/libxml2
includes:             libxml/xmlIO.h libxml/xmlmemory.h
depends:              base-4.16.4.0 bytestring-0.11.4.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-libxml/html/libxml.haddock
haddock-html:         /usr/share/doc/haskell-libxml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libxml-0.1.1-23.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libxml
version:              0.1.1
visibility:           public
id:                   libxml-0.1.1-6KlIDn8Mr6X9ZPUXHhuxY5
key:                  libxml-0.1.1-6KlIDn8Mr6X9ZPUXHhuxY5
license:              BSD-3-Clause
copyright:            2006, Lemmih
maintainer:           Lemmih (lemmih@gmail.com)
author:               Lemmih (lemmih@gmail.com)
synopsis:             Binding to libxml2
description:
    Minimal binding to libxml2. Additional functions will be added when needed.

category:             XML
abi:                  31b1758a91cf6bec6f084d3a4200f5ae
exposed:              True
exposed-modules:
    Text.XML.LibXML Text.XML.LibXML.Internals Text.XML.LibXML.Parser
    Text.XML.LibXML.Tree Text.XML.LibXML.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/libxml-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/libxml-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/libxml-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libxml
hs-libraries:         HSlibxml-0.1.1-6KlIDn8Mr6X9ZPUXHhuxY5
extra-libraries:      xml2
include-dirs:         /usr/include/libxml2
includes:             libxml/xmlIO.h libxml/xmlmemory.h
depends:              base-4.17.2.1 bytestring-0.11.5.3 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-libxml/html/libxml.haddock
haddock-html:         /usr/share/doc/haskell-libxml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
